import { isDevMode, Component, Inject, Input, EventEmitter, Output, ViewChild, NgModule, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import { MatDialogRef, MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import { TranslateService, TranslateModule } from '@ngx-translate/core';
import { FormBuilder, ReactiveFormsModule } from '@angular/forms';
import { distinctUntilChanged, debounceTime } from 'rxjs/operators';
import { __extends } from 'tslib';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatTooltipModule } from '@angular/material/tooltip';
import { CommonModule } from '@angular/common';
import { fromEvent } from 'rxjs';
import { MatIconModule } from '@angular/material/icon';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ErrorDialog = /** @class */ (function () {
    function ErrorDialog(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    /**
     * @return {?}
     */
    ErrorDialog.prototype.onNoClick = /**
     * @return {?}
     */
    function () {
        this.dialogRef.close();
    };
    /**
     * @param {?} e
     * @param {?=} data
     * @return {?}
     */
    ErrorDialog.extractErrorInfo = /**
     * @param {?} e
     * @param {?=} data
     * @return {?}
     */
    function (e, data) {
        if (data === void 0) { data = {}; }
        return Object.assign(data, {
            showDetails: isDevMode(),
            message: e.message
        });
    };
    /**
     * show error popup if needed
     * @param dialog dialog factory
     * @param e error
     * @param opts
     */
    /**
     * show error popup if needed
     * @param {?} dialog dialog factory
     * @param {?} e error
     * @param {?=} opts
     * @return {?}
     */
    ErrorDialog.openErrorDialog = /**
     * show error popup if needed
     * @param {?} dialog dialog factory
     * @param {?} e error
     * @param {?=} opts
     * @return {?}
     */
    function (dialog, e, opts) {
        if (opts === void 0) { opts = {}; }
        /** @type {?} */
        var config = Object.assign({
            canBeClosed: true,
            closeOnNavigation: true,
            panelClass: 'dialog-layout',
            disableClose: false,
        }, opts);
        config.data = ErrorDialog.extractErrorInfo(e, config.data);
        console.log('openErrorDialog: ', config);
        /** @type {?} */
        var dialogRef = dialog.open(ErrorDialog, config);
        dialogRef.disableClose = false;
        dialogRef.afterClosed().subscribe((/**
         * @param {?} result
         * @return {?}
         */
        function (result) {
            console.log('The dialog was closed', result);
        }));
        console.log(e);
        return dialogRef;
    };
    ErrorDialog.decorators = [
        { type: Component, args: [{
                    selector: 'base-error-dialog',
                    template: "<h2>ERROR</h2>\n<p>{{data.message}}</p>\n<mat-dialog-content>\n\n  <div class=\"error-info\">\n    <table class=\"info-grid\">\n      <tbody>\n      <tr *ngIf=\"data.status\"><td class=\"label\">Status</td><td class=\"val\">{{data.status}}</td></tr>\n      <tr *ngIf=\"data.code\"><td class=\"label\">Code</td><td class=\"val\">{{data.code}}</td></tr>\n      <tr *ngIf=\"data.link\"><td class=\"label\">Link</td><td class=\"val\">{{data.link}}</td></tr>\n      <tr *ngIf=\"data.request\"><td class=\"label\">Request</td><td class=\"val\">{{data.request}}</td></tr>\n      <tr *ngIf=\"data.operation\"><td class=\"label\">Operation</td><td class=\"val\">{{data.operation}}</td></tr>\n      <tr *ngIf=\"data.component\"><td class=\"label\">Component</td><td class=\"val\">{{data.component}}</td></tr>\n      <tr *ngIf=\"data.developerMessage\"><td class=\"label\">Dev Message:</td><td class=\"val\">{{data.developerMessage}}</td></tr>\n      </tbody>\n    </table>\n  </div>\n\n</mat-dialog-content>\n\n<mat-dialog-actions>\n    <button type=\"button\" class=\"cmd\" matDialogClose mat-raised-button color=\"primary\">Close</button>\n</mat-dialog-actions>\n"
                }] }
    ];
    /** @nocollapse */
    ErrorDialog.ctorParameters = function () { return [
        { type: MatDialogRef },
        { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
    ]; };
    return ErrorDialog;
}());
if (false) {
    /** @type {?} */
    ErrorDialog.prototype.dialogRef;
    /** @type {?} */
    ErrorDialog.prototype.data;
}
var ErrorDialogHandler = /** @class */ (function () {
    function ErrorDialogHandler(dialog) {
        this.dialog = dialog;
    }
    /**
     * @param {?} error
     * @return {?}
     */
    ErrorDialogHandler.prototype.handleError = /**
     * @param {?} error
     * @return {?}
     */
    function (error) {
        console.warn("ErrorDialogHandler handleError:", error);
        ErrorDialog.openErrorDialog(this.dialog, error);
    };
    return ErrorDialogHandler;
}());
if (false) {
    /**
     * @type {?}
     * @private
     */
    ErrorDialogHandler.prototype.dialog;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var BaseDateComponent = /** @class */ (function () {
    function BaseDateComponent(translate) {
        this.translate = translate;
        this.format = 'day';
        this.formatTip = 'date';
    }
    /**
     * @return {?}
     */
    BaseDateComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        if (this.translate != null) {
            this.format = this.translatePattern(this.format, 'yyyy-MM-dd');
            if ('false' !== this.formatTip) {
                this.formatTip = this.translatePattern(this.formatTip, 'yyyy-MM-dd HH:mm:ss Z');
            }
        }
    };
    /**
     * @param {?} key
     * @param {?} fallback
     * @return {?}
     */
    BaseDateComponent.prototype.translatePattern = /**
     * @param {?} key
     * @param {?} fallback
     * @return {?}
     */
    function (key, fallback) {
        /** @type {?} */
        var value = fallback;
        if (BaseDateComponent.FORMAT_NAMES.indexOf(key) !== -1) {
            this.translate.get(BaseDateComponent.RES_PREFIX + key).subscribe((/**
             * @param {?} result
             * @return {?}
             */
            function (result) {
                value = result;
            }));
        }
        return value;
    };
    BaseDateComponent.RES_PREFIX = 'DateFormat.';
    BaseDateComponent.FORMAT_NAMES = ['day', 'date', 'full', 'time', 'year'];
    BaseDateComponent.decorators = [
        { type: Component, args: [{
                    selector: 'base-date',
                    template: "<span *ngIf=\"data\"\n      [matTooltip]=\"formatTip != 'false' ? (data|date:formatTip) : null\">{{data|date:format}}</span>\n"
                }] }
    ];
    /** @nocollapse */
    BaseDateComponent.ctorParameters = function () { return [
        { type: TranslateService }
    ]; };
    BaseDateComponent.propDecorators = {
        data: [{ type: Input }],
        format: [{ type: Input }],
        formatTip: [{ type: Input }]
    };
    return BaseDateComponent;
}());
if (false) {
    /** @type {?} */
    BaseDateComponent.RES_PREFIX;
    /** @type {?} */
    BaseDateComponent.FORMAT_NAMES;
    /** @type {?} */
    BaseDateComponent.prototype.data;
    /** @type {?} */
    BaseDateComponent.prototype.format;
    /** @type {?} */
    BaseDateComponent.prototype.formatTip;
    /**
     * @type {?}
     * @protected
     */
    BaseDateComponent.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var BaseChangeComponent = /** @class */ (function () {
    function BaseChangeComponent() {
        this.format = 'day';
    }
    /**
     * @return {?}
     */
    BaseChangeComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    BaseChangeComponent.decorators = [
        { type: Component, args: [{
                    selector: 'base-change',
                    template: "<!--<base-date [data]=\"data?.date\"></base-date>-->\n<base-date\n        [data]=\"data?.date\"\n        [format]=\"format\"\n        formatTip=\"false\" [matTooltip]=\"data?.user\">\n</base-date>\n"
                }] }
    ];
    /** @nocollapse */
    BaseChangeComponent.ctorParameters = function () { return []; };
    BaseChangeComponent.propDecorators = {
        data: [{ type: Input }],
        format: [{ type: Input }]
    };
    return BaseChangeComponent;
}());
if (false) {
    /** @type {?} */
    BaseChangeComponent.prototype.data;
    /** @type {?} */
    BaseChangeComponent.prototype.format;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var TableSearchComponent = /** @class */ (function () {
    function TableSearchComponent(fb) {
        this.fb = fb;
        this.changed = new EventEmitter();
        this.debounceTime = 700;
        this.suffix = '*';
    }
    /**
     * @return {?}
     */
    TableSearchComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this.formGroup = this.fb.group({
            keyword: [null, null]
        });
        this.formGroup.valueChanges.pipe(distinctUntilChanged(), debounceTime(this.debounceTime)).subscribe((/**
         * @param {?} val
         * @return {?}
         */
        function (val) {
            if (!(val.keyword === null)) {
                val.keyword = val.keyword + _this.suffix;
            }
            _this.changed.emit(val);
        }));
    };
    TableSearchComponent.decorators = [
        { type: Component, args: [{
                    selector: 'table-search',
                    template: "<form [formGroup]=\"formGroup\">\n  <mat-form-field>\n    <mat-label>Suchen</mat-label>\n    <input matInput formControlName=\"keyword\" type=\"search\" nullValue/>\n  </mat-form-field>\n</form>\n"
                }] }
    ];
    /** @nocollapse */
    TableSearchComponent.ctorParameters = function () { return [
        { type: FormBuilder }
    ]; };
    TableSearchComponent.propDecorators = {
        changed: [{ type: Output }]
    };
    return TableSearchComponent;
}());
if (false) {
    /** @type {?} */
    TableSearchComponent.prototype.changed;
    /** @type {?} */
    TableSearchComponent.prototype.formGroup;
    /** @type {?} */
    TableSearchComponent.prototype.debounceTime;
    /** @type {?} */
    TableSearchComponent.prototype.suffix;
    /**
     * @type {?}
     * @private
     */
    TableSearchComponent.prototype.fb;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ObjectNotFoundDialogComponent = /** @class */ (function (_super) {
    __extends(ObjectNotFoundDialogComponent, _super);
    function ObjectNotFoundDialogComponent(dialogRef, data) {
        var _this = _super.call(this, dialogRef, data) || this;
        _this.dialogRef = dialogRef;
        _this.data = data;
        return _this;
    }
    /**
     * @return {?}
     */
    ObjectNotFoundDialogComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    /**
     * @param {?} dialog
     * @param {?} e
     * @param {?=} opts
     * @return {?}
     */
    ObjectNotFoundDialogComponent.openObjectNotFoundDialog = /**
     * @param {?} dialog
     * @param {?} e
     * @param {?=} opts
     * @return {?}
     */
    function (dialog, e, opts) {
        if (opts === void 0) { opts = {}; }
        /** @type {?} */
        var config = Object.assign({
            canBeClosed: true,
            closeOnNavigation: true,
            panelClass: 'dialog-layout',
            disableClose: false,
        }, opts);
        config.data = ObjectNotFoundDialogComponent.extractErrorInfo(e, config.data);
        console.log('openErrorDialog: ', config);
        /** @type {?} */
        var dialogRef = dialog.open(ObjectNotFoundDialogComponent, config);
        dialogRef.disableClose = false;
        return dialogRef;
    };
    ObjectNotFoundDialogComponent.decorators = [
        { type: Component, args: [{
                    selector: 'app-object-not-found-dialog',
                    template: "<h2>OBJECT NOT FOUND</h2>\n<p>{{data.message}}</p>\n<mat-dialog-content>\n\n  <div class=\"error-info\">\n    <table class=\"info-grid\">\n      <tbody>\n      <tr *ngIf=\"data.status\"><td class=\"label\">Status</td><td class=\"val\">{{data.status}}</td></tr>\n      <tr *ngIf=\"data.code\"><td class=\"label\">Code</td><td class=\"val\">{{data.code}}</td></tr>\n      <tr *ngIf=\"data.link\"><td class=\"label\">Link</td><td class=\"val\">{{data.link}}</td></tr>\n      <tr *ngIf=\"data.request\"><td class=\"label\">Request</td><td class=\"val\">{{data.request}}</td></tr>\n      <tr *ngIf=\"data.operation\"><td class=\"label\">Operation</td><td class=\"val\">{{data.operation}}</td></tr>\n      <tr *ngIf=\"data.component\"><td class=\"label\">Component</td><td class=\"val\">{{data.component}}</td></tr>\n      <tr *ngIf=\"data.developerMessage\"><td class=\"label\">Dev Message:</td><td class=\"val\">{{data.developerMessage}}</td></tr>\n      </tbody>\n    </table>\n  </div>\n\n</mat-dialog-content>\n\n<mat-dialog-actions>\n  <button mat-raised-button type=\"button\" color=\"accent\" [mat-dialog-close]=\"true\">{{ 'CMD.delete' | translate }}</button>\n  <button mat-button type=\"button\" [mat-dialog-close]=\"false\">{{ 'CMD.cancel' | translate }}</button>\n</mat-dialog-actions>\n"
                }] }
    ];
    /** @nocollapse */
    ObjectNotFoundDialogComponent.ctorParameters = function () { return [
        { type: MatDialogRef },
        { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
    ]; };
    return ObjectNotFoundDialogComponent;
}(ErrorDialog));
if (false) {
    /** @type {?} */
    ObjectNotFoundDialogComponent.prototype.dialogRef;
    /** @type {?} */
    ObjectNotFoundDialogComponent.prototype.data;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var SearchFieldComponent = /** @class */ (function () {
    function SearchFieldComponent() {
    }
    /**
     * @return {?}
     */
    SearchFieldComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        if (this.searchElem) {
            fromEvent(this.searchElem.nativeElement, 'keyup')
                .pipe(debounceTime(this.debounceTime), distinctUntilChanged())
                .subscribe((/**
             * @param {?} event
             * @return {?}
             */
            function (event) {
                /** @type {?} */
                var value = _this.searchElem.nativeElement.value;
                if (value == '')
                    value = null;
                // let filter = this.dataSource.filterSubject.value;
                // let filter = this.filter;
                // filter.keyword = value
                // this.reload();
                console.log("SearchFieldComponent keyup", value);
            }));
        }
    };
    /**
     * @param {?} ev
     * @return {?}
     */
    SearchFieldComponent.prototype.onSearch = /**
     * @param {?} ev
     * @return {?}
     */
    function (ev) {
        console.log("SearchFieldComponent onSearch", ev);
    };
    SearchFieldComponent.decorators = [
        { type: Component, args: [{
                    selector: 'base-search-field',
                    template: "<div class=\"field-wrap\">\n    <div class=\"field-box trans-icon\">\n        <input #searchField type=\"text\"/>\n        <button (click)=\"onSearch($event)\" type=\"button\">\n            <i><mat-icon>search</mat-icon></i>\n        </button>\n    </div>\n</div>\n",
                    styles: [""]
                }] }
    ];
    /** @nocollapse */
    SearchFieldComponent.ctorParameters = function () { return []; };
    SearchFieldComponent.propDecorators = {
        searchElem: [{ type: ViewChild, args: ['searchField', { static: true },] }],
        debounceTime: [{ type: Input }]
    };
    return SearchFieldComponent;
}());
if (false) {
    /** @type {?} */
    SearchFieldComponent.prototype.searchElem;
    /** @type {?} */
    SearchFieldComponent.prototype.debounceTime;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var ChainBaseComp = /** @class */ (function () {
    function ChainBaseComp() {
    }
    ChainBaseComp.decorators = [
        { type: NgModule, args: [{
                    declarations: [
                        ErrorDialog,
                        ObjectNotFoundDialogComponent,
                        TableSearchComponent,
                        BaseChangeComponent,
                        BaseDateComponent,
                        SearchFieldComponent
                    ],
                    imports: [
                        ReactiveFormsModule,
                        MatFormFieldModule,
                        MatTooltipModule,
                        MatIconModule,
                        CommonModule,
                        MatDialogModule,
                        TranslateModule
                    ],
                    exports: [
                        ErrorDialog,
                        ObjectNotFoundDialogComponent,
                        TableSearchComponent,
                        BaseChangeComponent,
                        BaseDateComponent
                    ],
                    entryComponents: [
                        ObjectNotFoundDialogComponent,
                        //ValidationResultDialogComponent,
                        ErrorDialog
                    ],
                    schemas: [CUSTOM_ELEMENTS_SCHEMA]
                },] }
    ];
    return ChainBaseComp;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var TYPE_INVOICE = "INVOICE";
/**
 * @deprecated
 */
var  /**
 * @deprecated
 */
AddressUtils = /** @class */ (function () {
    //public static readonly TYPE_INVOICE = "INVOICE";
    function AddressUtils() {
    }
    /**
     * @param {?} address
     * @param {?} type
     * @return {?}
     */
    AddressUtils.findAddressByType = /**
     * @param {?} address
     * @param {?} type
     * @return {?}
     */
    function (address, type) {
        console.log("AddressUtils.findAddressByType");
        console.log("AddressUtils.findAddressByType", address);
        console.log("AddressUtils.findAddressByType", type);
        return address.filter((/**
         * @param {?} val
         * @return {?}
         */
        function (val) { return val.type != null; })).find((/**
         * @param {?} val
         * @return {?}
         */
        function (val) { return val.type === TYPE_INVOICE; }));
        // return address.filter(val => val.type ==true).find(value => value.type == TYPE_INVOICE);
        //  return null;
        // throw new Error("fubar ts")
    };
    /**
     * @param {?} fb
     * @param {?=} initial
     * @param {?=} validators
     * @return {?}
     */
    AddressUtils.getFormGroup = /**
     * @param {?} fb
     * @param {?=} initial
     * @param {?=} validators
     * @return {?}
     */
    function (fb, initial, validators) {
        /** @type {?} */
        var group = fb.group({
            type: [null, null],
            street: [null, null],
            houseNumber: [null, null],
            countryCode: [null, null],
            city: [null, null],
            zipCode: [null, null],
            desc: [null, null]
        });
        if (initial) {
            group.patchValue(initial);
        }
        return group;
    };
    /**
     * @param {?} fa
     * @param {?} fb
     * @param {?=} initial
     * @return {?}
     */
    AddressUtils.addAddressToFormArray = /**
     * @param {?} fa
     * @param {?} fb
     * @param {?=} initial
     * @return {?}
     */
    function (fa, fb, initial) {
        /** @type {?} */
        var formArray = (/** @type {?} */ (fa));
        formArray.push(this.getFormGroup(fb, initial));
    };
    /**
     * @param {?} fa
     * @param {?} fb
     * @param {?=} initial
     * @return {?}
     */
    AddressUtils.addAndGetAddress = /**
     * @param {?} fa
     * @param {?} fb
     * @param {?=} initial
     * @return {?}
     */
    function (fa, fb, initial) {
        /** @type {?} */
        var formArray = (/** @type {?} */ (fa));
        /** @type {?} */
        var group = this.getFormGroup(fb, initial);
        formArray.push(group);
        return group;
    };
    return AddressUtils;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { AddressUtils, BaseChangeComponent, BaseDateComponent, ChainBaseComp, ErrorDialog, ErrorDialogHandler, ObjectNotFoundDialogComponent, TableSearchComponent, SearchFieldComponent as ɵa };
//# sourceMappingURL=yukawa-chain-base-angular-comp.js.map
